ResourceLimit

Enum ResourceLimit 

pub enum ResourceLimit {
    StackSize = 0,
    PrintfFifoSize = 1,
    MallocHeapSize = 2,
    DeviceRuntimeSynchronizeDepth = 3,
    DeviceRuntimePendingLaunchCount = 4,
    MaxL2FetchGranularity = 5,
    // some variants omitted
}
This enumeration represents the limited resources which can be accessed through CurrentContext::get_resource_limit and CurrentContext::set_resource_limit.

Variants



StackSize = 0

The size in bytes of each GPU thread stack



PrintfFifoSize = 1

The size in bytes of the FIFO used by the printf() device system call.



MallocHeapSize = 2

The size in bytes of the heap used by the malloc() and free() device system calls.

Note that this is used for memory allocated within a kernel launch; it is not related to the device memory allocated by the host.



DeviceRuntimeSynchronizeDepth = 3

The maximum nesting depth of a grid at which a thread can safely call cudaDeviceSynchronize() to wait on child grid launches to complete.



DeviceRuntimePendingLaunchCount = 4

The maximum number of outstanding device runtime launches that can be made from the current context.



MaxL2FetchGranularity = 5

L2 cache fetch granularity