pub enum EventStatus {
Ready,
NotReady,
}Expand description
Status enum that represents the current status of an event.
Variants
Ready
Ready indicates that all work captured by the event has been completed.
The CUDA documentation states that for Unified Memory, EventStatus::Ready is
equivalent to having called Event::synchronize.
NotReady
EventStatus::NotReady indicates that the work captured by the event is still
incomplete.