BlockSize

Struct BlockSize 

pub struct BlockSize {
    pub x: u32,
    pub y: u32,
    pub z: u32,
}
Dimensions of a thread block, or the number of threads in a block.

Each component of a BlockSize must be at least 1. The maximum size depends on your device’s compute capability, but maximums of x = 1024, y = 1024, z = 64 are common. In addition, the limit on total number of threads in a block (x * y * z) is also defined by the compute capability, typically 1024. Launching a kernel with a block size greater than these limits will cause an error.

Fields

x: u32

X dimension of each thread block

y: u32

Y dimension of each thread block

z: u32

Z dimension of each thread block

Implementations

Source

impl BlockSize

pub fn x(x: u32) -> BlockSize

Create a one-dimensional block of x threads

pub fn xy(x: u32, y: u32) -> BlockSize

Create a two-dimensional block of x * y threads

pub fn xyz(x: u32, y: u32, z: u32) -> BlockSize

Create a three-dimensional block of x * y * z threads