GridSize

Struct GridSize 

pub struct GridSize {
    pub x: u32,
    pub y: u32,
    pub z: u32,
}
Dimensions of a grid, or the number of thread blocks in a kernel launch.

Each component of a GridSize must be at least 1. The maximum size depends on your device’s compute capability, but maximums of x = (2^31)-1, y = 65535, z = 65535 are common. Launching a kernel with a grid size greater than these limits will cause an error.

Fields

x: u32

Width of grid in blocks

y: u32

Height of grid in blocks

z: u32

Depth of grid in blocks

Implementations

Source

impl GridSize

pub fn x(x: u32) -> GridSize

Create a one-dimensional grid of x blocks

pub fn xy(x: u32, y: u32) -> GridSize

Create a two-dimensional grid of x * y blocks

pub fn xyz(x: u32, y: u32, z: u32) -> GridSize

Create a three-dimensional grid of x * y * z blocks